Create synthetic datasets based on a correlation table. Additional functions can be used to rescale, transform, and reverse code variables.
| Package: | gendata |
| Type: | Package |
| Version: | 1.1 |
| Date: | 2012-02-27 |
| License: | GPL-3 |
Additional functions are for modifying the dataset.
genmvnorm: creates the dataset (generates a multivariate normal dataset). recalib : for rescaling the dataset dtrans : for giving a variable a new mean and standard deviation revcode : for reverse coding a variable
Fan, X., Felsovalyi, A., Sivo, S., & Keenan, S. (2002). SAS for Monte Carlo studies: A guide for quantitative researchers. SAS Institute.